.. astm documentation master file, created by
   sphinx-quickstart on Sat Sep 15 16:35:42 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to astm's documentation!
================================

Contents:

.. toctree::
   :maxdepth: 2
   :numbered:

   constants
   codecs
   mapping
   records
   asynclib
   protocol
   modules
   changes
   licence


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

